@@ -1,33 +1,34 @@
 #' Interface between R and vcglib libraries for mesh operations
-#' 
+#'
 #' Provides meshing functionality from vcglib (meshlab) for R. E.g. mesh
 #' smoothing, mesh decimation, closest point search.
-#' 
+#'
 #' \tabular{ll}{
 #' Package: \tab Rvcg\cr
 #' Type: \tab Package\cr
-#' Version: \tab 0.22.2\cr
-#' Date: \tab 2023-12-04\cr
+#' Version: \tab 0.23\cr
+#' Date: \tab 2024-06-25\cr
 #' License: \tab GPL\cr
 #' LazyLoad: \tab yes\cr }
-#' 
-#' @name Rvcg-package
-#' @aliases Rvcg-package Rvcg
-#' @docType package
+#'
 #' @author Stefan Schlager
-#' 
+#'
 #' Maintainer: Stefan Schlager <zarquon42@@gmail.com>
 #' @references To be announced
 #' @keywords package
+"_PACKAGE"
+
+## usethis namespace: start
 #' @import grDevices stats utils
-#' @importFrom Rcpp evalCpp 
+#' @importFrom Rcpp evalCpp
 #' @useDynLib Rvcg, .registration=TRUE
+## usethis namespace: end
 NULL
 
 #' Example mesh and landmarks
 #'
 #' A triangular mesh representing a human face - called by data(humface)
-#' 
+#'
 #' @name humface
 #' @aliases humface humface.lm humfaceClean
 #' @docType data
@@ -43,7 +44,7 @@ NULL
 #' dummyhead - dummy head and landmarks
 #'
 #' A triangular mesh representing a dummyhead - called by data(dummyhead)
-#' 
+#'
 #' @name dummyhead
 #' @aliases dummyhead.mesh dummyhead.lm
 #' @docType data
@@ -51,7 +52,7 @@ NULL
 #'
 #' \code{dummyhead.lm}: landmarks on mesh 'dummyhead'
 #' @keywords datasets
-#' 
+#'
 NULL
 
 
@@ -64,7 +65,7 @@ NULL
 NULL
 
 #' @rdname Rvcg-deprecated
-#' @export 
+#' @export
 checkNormOrient <- function (...)
 {
   .Deprecated("checkFaceOrientation", package="Rvcg")
