@@ -69,7 +69,7 @@ RcppExport SEXP Rintersect(SEXP vb_ , SEXP it_, SEXP ioclost_, SEXP normals_, SE
       // run search 
 #pragma omp parallel for firstprivate(minDist,maxDist,static_grid,mf) schedule(static) num_threads(threads)
 
-      for (unsigned int i=0; i < refmesh.vn; i++) {
+      for (int i=0; i < refmesh.vn; i++) {
     	float t, t1;
 	t=0; t1=0;
 	vcg::Ray3f ray;
@@ -138,10 +138,10 @@ RcppExport SEXP Rintersect(SEXP vb_ , SEXP it_, SEXP ioclost_, SEXP normals_, SE
 				);
     }
   } catch (std::exception& e) {
-    ::Rf_error( e.what());
+    forward_exception_to_r( e );
   } catch (...) {
     ::Rf_error("unknown exception");
-  }
+  } return R_NilValue; 
 }
     
 
